Sum positive numbers via their logarithms Given x and y, this function returns log(exp(x) + exp(y)).
Source:R/logsum.R
sum_of_logs.RdSum positive numbers via their logarithms Given x and y, this function returns log(exp(x) + exp(y)).
R/logsum.R
sum_of_logs.RdSum positive numbers via their logarithms Given x and y, this function returns log(exp(x) + exp(y)).