Calculate barrier penalty to add to objective function inside barrier algorithm
Source:R/calculate_log_penalty.R
calculate_log_penalty.RdCalculate barrier penalty to add to objective function inside barrier algorithm
Arguments
- varying_lr_df
A data frame containing values of parameters that are treated as unknown, with relative abundance parameters represented on the log ratio scale (i.e., as phi and phi_tilde)
- fixed_df
A data frame containing values of parameters that are treated as known
- barrier_t
The current value of t, the barrier penalty parameter